diff --git a/Emby.Server.Implementations/ApplicationHost.cs b/Emby.Server.Implementations/ApplicationHost.cs
index eca40b0f2a..a9baf893cc 100644
--- a/Emby.Server.Implementations/ApplicationHost.cs
+++ b/Emby.Server.Implementations/ApplicationHost.cs
@@ -1148,7 +1148,7 @@ namespace Emby.Server.Implementations
OperatingSystem = OperatingSystem.Id.ToString(),
ServerName = FriendlyName,
LocalAddress = localAddress,
- StartupCompleted = _configurationManager.CommonConfiguration.IsStartupWizardCompleted
+ StartupWizardCompleted = _configurationManager.CommonConfiguration.IsStartupWizardCompleted
};
}
diff --git a/MediaBrowser.Model/System/PublicSystemInfo.cs b/MediaBrowser.Model/System/PublicSystemInfo.cs
index 012001aea7..d2f7556a51 100644
--- a/MediaBrowser.Model/System/PublicSystemInfo.cs
+++ b/MediaBrowser.Model/System/PublicSystemInfo.cs
@@ -24,7 +24,7 @@ namespace MediaBrowser.Model.System
public string Version { get; set; }
///
- /// The product name. This is the AssemblyProduct name.
+ /// Gets or sets the product name. This is the AssemblyProduct name.
///
public string ProductName { get; set; }
@@ -41,9 +41,9 @@ namespace MediaBrowser.Model.System
public string Id { get; set; }
///
/// Gets or sets a value indicating whether startup is completed.
///
/// The startup completion status.
- public bool StartupCompleted { get; set; }
+ public bool StartupWizardCompleted { get; set; }
}
}
@@ -41,9 +41,9 @@ namespace MediaBrowser.Model.System
public string Id { get; set; }
///
- /// Gets or sets a value indicating whether startup is completed.
+ /// Gets or sets a value indicating whether the startup wizard is completed.
///
/// The startup completion status.